@@ -118,26 +118,27 @@ file_lock_setup(struct flock *fl, short type)
  * Unlock a previously locked file.
  */
 void
-file_unlock(int lockfd, const char *lock_desc)
+file_unlock(int lockfd, const char *lockfile, const char *lockdesc)
 {
 	struct flock fl;
 
 	if (lockfd < 0)
-		internerr("lock fd is %d < 0", lockfd);
+		internerr("%s (%s) fd is %d < 0", lockdesc, lockfile, lockfd);
 
 	file_lock_setup(&fl, F_UNLCK);
 
 	if (fcntl(lockfd, F_SETLK, &fl) == -1)
-		ohshite(_("unable to unlock %s"), lock_desc);
+		ohshite(_("unable to unlock %s"), lockdesc);
 }
 
 static void
 file_unlock_cleanup(int argc, void **argv)
 {
 	int lockfd = *(int *)argv[0];
-	const char *lock_desc = argv[1];
+	const char *lockfile = argv[1];
+	const char *lockdesc = argv[2];
 
-	file_unlock(lockfd, lock_desc);
+	file_unlock(lockfd, lockfile, lockdesc);
 }
 
 /**
@@ -188,13 +189,26 @@ file_lock(int *lockfd, enum file_lock_flags flags, const char *filename,
 		lock_cmd = F_SETLK;
 
 	if (fcntl(*lockfd, lock_cmd, &fl) == -1) {
-		if (errno == EACCES || errno == EAGAIN)
-			ohshit(_("%s is locked by another process"), desc);
-		else
+		const char *warnmsg;
+
+		if (errno != EACCES && errno != EAGAIN)
 			ohshite(_("unable to lock %s"), desc);
+
+		warnmsg = _("Note: removing the lock file is always wrong, "
+		            "and can end up damaging the\n"
+		            "locked area and the entire system. "
+		            "See <https://wiki.debian.org/Teams/Dpkg/FAQ>.");
+
+		file_lock_setup(&fl, F_WRLCK);
+		if (fcntl(*lockfd, F_GETLK, &fl) == -1)
+			ohshit(_("%s was locked by another process\n%s"),
+			       desc, warnmsg);
+
+		ohshit(_("%s was locked by another process with pid %d\n%s"),
+		       desc, fl.l_pid, warnmsg);
 	}
 
-	push_cleanup(file_unlock_cleanup, ~0, 2, lockfd, desc);
+	push_cleanup(file_unlock_cleanup, ~0, 3, lockfd, filename, desc);
 }
 
 void
